==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.md <==
# AmazonCloudFrontEdgeLocation


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')
```



| Illustration | AmazonCloudFrontEdgeLocation | AmazonCloudFrontEdgeLocationCard | AmazonCloudFrontEdgeLocationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.png) | ![illustration for AmazonCloudFrontEdgeLocation](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.Local.png) | ![illustration for AmazonCloudFrontEdgeLocationCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocationCard.Local.png) | ![illustration for AmazonCloudFrontEdgeLocationGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocationGroup.Local.png) |




## AmazonCloudFrontEdgeLocation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocation
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocation('AmazonCloudFrontEdgeLocation', 'Amazon Cloud Front Edge Location', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocation
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocation('AmazonCloudFrontEdgeLocation', 'Amazon Cloud Front Edge Location', 'an optional tech label')
@enduml
```

## AmazonCloudFrontEdgeLocationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationCard('AmazonCloudFrontEdgeLocationCard', 'Amazon Cloud Front Edge Location Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationCard('AmazonCloudFrontEdgeLocationCard', 'Amazon Cloud Front Edge Location Card', 'an optional description')
@enduml
```

## AmazonCloudFrontEdgeLocationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationGroup('AmazonCloudFrontEdgeLocationGroup', 'Amazon Cloud Front Edge Location Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationGroup('AmazonCloudFrontEdgeLocationGroup', 'Amazon Cloud Front Edge Location Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.md <==
# AmazonCloudFrontEdgeLocation


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')
```



| Illustration | AmazonCloudFrontEdgeLocation | AmazonCloudFrontEdgeLocationCard | AmazonCloudFrontEdgeLocationGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.png) | ![illustration for AmazonCloudFrontEdgeLocation](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation.Local.png) | ![illustration for AmazonCloudFrontEdgeLocationCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocationCard.Local.png) | ![illustration for AmazonCloudFrontEdgeLocationGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocationGroup.Local.png) |




## AmazonCloudFrontEdgeLocation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocation
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocation('AmazonCloudFrontEdgeLocation', 'Amazon Cloud Front Edge Location', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocation
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocation('AmazonCloudFrontEdgeLocation', 'Amazon Cloud Front Edge Location', 'an optional tech label')
@enduml
```

## AmazonCloudFrontEdgeLocationCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationCard('AmazonCloudFrontEdgeLocationCard', 'Amazon Cloud Front Edge Location Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationCard('AmazonCloudFrontEdgeLocationCard', 'Amazon Cloud Front Edge Location Card', 'an optional description')
@enduml
```

## AmazonCloudFrontEdgeLocationGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationGroup('AmazonCloudFrontEdgeLocationGroup', 'Amazon Cloud Front Edge Location Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontEdgeLocationGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AmazonCloudFrontEdgeLocation')

' renders the element
AmazonCloudFrontEdgeLocationGroup('AmazonCloudFrontEdgeLocationGroup', 'Amazon Cloud Front Edge Location Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
